@@ -1,4 +1,4 @@
-# last modified 31 May 2005 by J. Fox
+# last modified 7 March 2006 by J. Fox
 
 specify.model <- function(file=""){
     ram <- scan(file=file, what=list(path="", par="", start=1, dump=""), sep=",", 
@@ -12,8 +12,12 @@ specify.model <- function(file=""){
 print.mod <- function(x, ...){
     path <- x[,1]
     parameter <- x[,2]
+    parameter[is.na(parameter)] <- "<fixed>"
     startvalue <- as.numeric(x[,3])
-    print(data.frame(Path=path, Parameter=parameter, StartValue=startvalue),
+    startvalue[is.na(startvalue)] <- " "
+    if (all(startvalue == " "))  print(data.frame(Path=path, Parameter=parameter),
+        right=FALSE)
+    else print(data.frame(Path=path, Parameter=parameter, StartValue=startvalue),
         right=FALSE)
     invisible(x)
     }
